# Examples of how to use spglib in your project

`example.c`, `example.F90`, and `example.py` in the following directories show
how to obtain spglib symmetry dataset from input crystal structure of Wurtzite
type. More examples, but not all, are found in `example_full.c`,
`example_full.F90`, and `example_full.py`.

- [C API](c_api/README.md)
- [Fortran API](fortran_api/README.md)
- [Python API](python_api/README.md)
